@@ -20,10 +20,13 @@
 
 #include "advancedplotassistant.h"
 
+#include <QAction>
+
 #include <QVBoxLayout>
-#include <KDialog>
-#include <KAction>
+#include <QPushButton>
+#include <QDialog>
 #include <KActionCollection>
+#include <KConfigGroup>
 #include "ui_advancedplotdialog.h"
 #include "ui_directivecontainer.h"
 #include "cantor_macros.h"
@@ -43,18 +46,25 @@ AdvancedPlotAssistant::~AdvancedPlotAssistant()
 void AdvancedPlotAssistant::initActions()
 {
     setXMLFile(QLatin1String("cantor_advancedplot_assistant.rc"));
-    KAction* advplot=new KAction(i18n("Advanced Plotting"), actionCollection());
+    QAction* advplot=new QAction(i18n("Advanced Plotting"), actionCollection());
     actionCollection()->addAction(QLatin1String("advancedplot_assistant"), advplot);
-    connect(advplot, &KAction::triggered, this, &AdvancedPlotAssistant::requested);
+    connect(advplot, &QAction::triggered, this, &AdvancedPlotAssistant::requested);
 }
 
 QStringList AdvancedPlotAssistant::run(QWidget* parent)
 {
-    QPointer<KDialog> dlg=new KDialog(parent);
+    QPointer<QDialog> dlg=new QDialog(parent);
     QWidget *widget=new QWidget(dlg);
     Ui::AdvancedPlotAssistantBase base;
     base.setupUi(widget);
-    dlg->setMainWidget(widget);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    dlg->setLayout(mainLayout);
+    mainLayout->addWidget(widget);
+
+    base.buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
+    base.buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
+    connect(base.buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()));
+    connect(base.buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()));
 
     //Casting the extension to correct type and checking it
     Cantor::AdvancedPlotExtension * plotter=dynamic_cast<Cantor::AdvancedPlotExtension*>
