@@ -20,9 +20,12 @@
 
 #include "importpackageassistant.h"
 
-#include <KDialog>
-#include <KAction>
+#include <QAction>
+
+#include <QDialog>
+#include <QPushButton>
 #include <KActionCollection>
+#include <KConfigGroup>
 #include "cantor_macros.h"
 #include "backend.h"
 #include "extension.h"
@@ -42,21 +45,28 @@ void ImportPackageAssistant::initActions()
 {
     setXMLFile(QLatin1String("cantor_import_package_assistant.rc"));
 
-    KAction* importpackage = new KAction(i18n("Import Package"), actionCollection());
+    QAction* importpackage = new QAction(i18n("Import Package"), actionCollection());
     actionCollection()->addAction(QLatin1String("importpackage_assistant"), importpackage);
-    connect(importpackage, &KAction::triggered, this, &ImportPackageAssistant::requested);
+    connect(importpackage, &QAction::triggered, this, &ImportPackageAssistant::requested);
 }
 
 QStringList ImportPackageAssistant::run(QWidget* parent)
 {
-    QPointer<KDialog> dlg=new KDialog(parent);
+    QPointer<QDialog> dlg=new QDialog(parent);
 
     QWidget* widget=new QWidget(dlg);
 
     Ui::ImportPackageAssistantBase base;
     base.setupUi(widget);
 
-    dlg->setMainWidget(widget);
+    base.buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
+    base.buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
+    connect(base.buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()));
+    connect(base.buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()));
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    dlg->setLayout(mainLayout);
+    mainLayout->addWidget(widget);
 
     QStringList result;
     if( dlg->exec())
