@@ -20,10 +20,13 @@
 
 #include "solveassistant.h"
 
-#include <KDialog>
-#include <KAction>
+#include <QAction>
+#include <QIcon>
+
+#include <QDialog>
 #include <KActionCollection>
-#include <KIcon>
+#include <KConfigGroup>
+#include <QPushButton>
 #include "ui_solvedlg.h"
 #include "cantor_macros.h"
 #include "backend.h"
@@ -42,19 +45,27 @@ SolveAssistant::~SolveAssistant()
 void SolveAssistant::initActions()
 {
     setXMLFile(QLatin1String("cantor_solve_assistant.rc"));
-    KAction* solve=new KAction(i18n("Solve equations"), actionCollection());
-    solve->setIcon(KIcon(icon()));
+    QAction* solve=new QAction(i18n("Solve equations"), actionCollection());
+    solve->setIcon(QIcon::fromTheme(icon()));
     actionCollection()->addAction(QLatin1String("solve_assistant"), solve);
-    connect(solve, &KAction::triggered, this, &SolveAssistant::requested);
+    connect(solve, &QAction::triggered, this, &SolveAssistant::requested);
 }
 
 QStringList SolveAssistant::run(QWidget* parent)
 {
-    QPointer<KDialog> dlg=new KDialog(parent);
+    QPointer<QDialog> dlg=new QDialog(parent);
     QWidget *widget=new QWidget(dlg);
     Ui::SolveAssistantBase base;
     base.setupUi(widget);
-    dlg->setMainWidget(widget);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    dlg->setLayout(mainLayout);
+    mainLayout->addWidget(widget);
+
+    base.buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
+    base.buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
+
+    connect(base.buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()) );
+    connect(base.buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()) );
 
     QStringList result;
     if( dlg->exec())
