@@ -23,7 +23,6 @@
 #include <QDebug>
 
 #include <KLocale>
-#include <KStandardDirs>
 
 #include "pythonutils.h"
 
@@ -183,7 +182,7 @@ QString PythonScriptExtension::runExternalScript(const QString& path)
 
 QString PythonScriptExtension::scriptFileFilter()
 {
-    return i18n("*.py|Python script file");
+    return i18n("Python script file (*.py)");
 }
 
 QString PythonScriptExtension::highlightingMode()
