@@ -41,6 +41,9 @@
 // required for the plotting interface of Qalculator
 #include <vector>
 
+#include <QDir>
+#include <QTemporaryFile>
+
 #include <KGlobal>
 #include <KMessageBox>
 #include <KColorScheme>
@@ -146,16 +149,16 @@ void QalculateExpression::evaluateSaveVariablesCommand()
     // he deserves unexpected behavior.
     std::string tmpCategory = "Temporary";
     std::string newCategory = "Cantor_Internal_Temporary";
-    for (int i = 0; i < variables.size(); ++i) {
+    for (size_t i = 0; i < variables.size(); ++i) {
 	if (variables[i]->category() == tmpCategory)
 	    variables[i]->setCategory(newCategory);
     }
 
     int res = CALCULATOR->saveVariables(fileName.toLatin1().data());
 
-    for (int i = 0; i < variables.size(); ++i) {
-	if (variables[i]->category() == newCategory)
-	    variables[i]->setCategory(tmpCategory);
+    for (size_t i = 0; i < variables.size(); ++i) {
+        if (variables[i]->category() == newCategory)
+            variables[i]->setCategory(tmpCategory);
     }
 
 
@@ -196,9 +199,9 @@ void QalculateExpression::evaluateLoadVariablesCommand()
     std::string tmpCategory = "Temporary";
     std::string newCategory = "Cantor_Internal_Temporary";
 
-    for (int i = 0; i < variables.size(); ++i) {
-	if (variables[i]->category() == newCategory)
-	    variables[i]->setCategory(tmpCategory);
+    for (size_t i = 0; i < variables.size(); ++i) {
+        if (variables[i]->category() == newCategory)
+            variables[i]->setCategory(tmpCategory);
     }
 
     setStatus(Done);
@@ -743,12 +746,11 @@ void QalculateExpression::evaluatePlotCommand()
 
     if (plotInline && plotParameters.filename.empty()) {
 	// TODO: get a temporary file name here
-	if (!m_tempFile) {
-	    m_tempFile = new KTemporaryFile();
+    if (!m_tempFile) {
 #ifdef WITH_EPS
-	    m_tempFile->setSuffix(QLatin1String(".eps"));
+        m_tempFile=new QTemporaryFile(QDir::tempPath() + QLatin1String("/cantor_qalculate-XXXXXX.eps" ));
 #else
-	    m_tempFile->setSuffix(QLatin1String(".png"));
+        m_tempFile=new QTemporaryFile(QDir::tempPath() + QLatin1String("/cantor_qalculate-XXXXXX.png"));
 #endif
 	    m_tempFile->open();
 	}
@@ -774,11 +776,11 @@ void QalculateExpression::evaluatePlotCommand()
 	     plotParameters.filename.substr(p-4,4) == QLatin1String(".eps")) ||
 	    (plotParameters.filetype == PLOT_FILETYPE_AUTO && p >= 3 &&
 	     plotParameters.filename.substr(p-3,3) == QLatin1String(".ps")))
-	    setResult(new Cantor::EpsResult(KUrl(plotParameters.filename.c_str())));
+        setResult(new Cantor::EpsResult(QUrl(QString::fromStdString(plotParameters.filename))));
 	else
-	    setResult(new Cantor::ImageResult(KUrl(plotParameters.filename.c_str())));
+        setResult(new Cantor::ImageResult(QUrl(QString::fromStdString(plotParameters.filename)));
 #else
-	setResult(new Cantor::ImageResult(KUrl(plotParameters.filename.c_str())));
+    setResult(new Cantor::ImageResult(QUrl::fromLocalFile(QString::fromStdString(plotParameters.filename))));
 #endif
 	setStatus(Cantor::Expression::Done);
     }
@@ -858,8 +860,8 @@ ParseOptions QalculateExpression::parseOptions()
 void QalculateExpression::deletePlotDataParameters
     (const std::vector<PlotDataParameters*>& plotDataParameterList)
 {
-    for(int i = 0; i < plotDataParameterList.size(); ++i)
-	delete plotDataParameterList[i];
+    for(size_t i = 0; i < plotDataParameterList.size(); ++i)
+        delete plotDataParameterList[i];
 }
 
 bool QalculateExpression::stringToBool(const QString &string, bool *ok)
@@ -955,7 +957,7 @@ void QalculateExpression::updateVariables(MathStructure command)
 	    m.format(*po);
 	    model->addVariable(QLatin1String(name.c_str()), QLatin1String(m.print(*po).c_str()));
 	}
-	for (int i = 0; i < current->countChildren(); ++i) {
+    for (size_t i = 0; i < current->countChildren(); ++i) {
 	    stack.push(current->getChild(i+1));
 	}
     }
