@@ -86,7 +86,7 @@ double ImageResultItem::height() const
 void ImageResultItem::saveResult()
 {
     Cantor::Result* res = result();
-    const QString& filename=KFileDialog::getSaveFileName(KUrl(), res->mimeType(), worksheet()->worksheetView());
+    const QString& filename=KFileDialog::getSaveFileName(QUrl(), res->mimeType(), worksheet()->worksheetView());
     qDebug()<<"saving result to "<<filename;
     res->save(filename);
 }
