@@ -21,17 +21,19 @@
 #include "variablemanagerwidget.h"
 
 #include <QLayout>
+#include <QIcon>
 #include <QTreeView>
 #include <QToolButton>
 #include <QAbstractItemModel>
 
-#include <KDialog>
-#include <KIcon>
+#include <QDialog>
+#include <QPushButton>
 #include <KLocale>
 #include <QDebug>
 #include <KIconLoader>
 #include <KFileDialog>
 #include <KMessageBox>
+#include <KConfigGroup>
 
 #include "session.h"
 #include "extension.h"
@@ -54,7 +56,7 @@ VariableManagerWidget::VariableManagerWidget(Cantor::Session* session, QWidget*
     int size=KIconLoader::global()->currentSize(KIconLoader::MainToolbar);
 
     m_newBtn=new QToolButton(this);
-    m_newBtn->setIcon(KIcon(QLatin1String("document-new")));
+    m_newBtn->setIcon(QIcon::fromTheme(QLatin1String("document-new")));
     m_newBtn->setToolTip(i18n("Add new variable"));
     m_newBtn->setIconSize(QSize(size, size));
     connect(m_newBtn, &QToolButton::clicked, this, &VariableManagerWidget::newVariable);
@@ -62,21 +64,21 @@ VariableManagerWidget::VariableManagerWidget(Cantor::Session* session, QWidget*
 
 
     m_loadBtn=new QToolButton(this);
-    m_loadBtn->setIcon(KIcon(QLatin1String("document-open")));
+    m_loadBtn->setIcon(QIcon::fromTheme(QLatin1String("document-open")));
     m_loadBtn->setToolTip(i18n("Load Variables"));
     m_loadBtn->setIconSize(QSize(size, size));
     connect(m_loadBtn, &QToolButton::clicked, this, &VariableManagerWidget::load);
     btnLayout->addWidget(m_loadBtn);
 
     m_saveBtn=new QToolButton(this);
-    m_saveBtn->setIcon(KIcon(QLatin1String("document-save")));
+    m_saveBtn->setIcon(QIcon::fromTheme(QLatin1String("document-save")));
     m_saveBtn->setToolTip(i18n("Store Variables"));
     m_saveBtn->setIconSize(QSize(size, size));
     connect(m_saveBtn, &QToolButton::clicked, this, &VariableManagerWidget::save);
     btnLayout->addWidget(m_saveBtn);
 
     m_clearBtn=new QToolButton(this);
-    m_clearBtn->setIcon(KIcon(QLatin1String("edit-clear")));
+    m_clearBtn->setIcon(QIcon::fromTheme(QLatin1String("edit-clear")));
     m_clearBtn->setToolTip(i18n("Clear Variables"));
     m_clearBtn->setIconSize(QSize(size, size));
     connect(m_clearBtn, &QToolButton::clicked, this, &VariableManagerWidget::clearVariables);
@@ -144,7 +146,7 @@ void VariableManagerWidget::clearVariables()
 
 void VariableManagerWidget::save()
 {
-    const QString file=KFileDialog::getSaveFileName(KUrl(),  QString(),  this);
+    const QString file=KFileDialog::getSaveFileName(QUrl(),  QString(),  this);
 
     Cantor::VariableManagementExtension* ext=
         dynamic_cast<Cantor::VariableManagementExtension*>(m_session->backend()->extension(QLatin1String("VariableManagementExtension")));
@@ -155,7 +157,7 @@ void VariableManagerWidget::save()
 
 void VariableManagerWidget::load()
 {
-    const QString file=KFileDialog::getOpenFileName(KUrl(),  QString(),  this);
+    const QString file=KFileDialog::getOpenFileName(QUrl(),  QString(),  this);
 
     Cantor::VariableManagementExtension* ext=
         dynamic_cast<Cantor::VariableManagementExtension*>(m_session->backend()->extension(QLatin1String("VariableManagementExtension")));
@@ -166,11 +168,20 @@ void VariableManagerWidget::load()
 
 void VariableManagerWidget::newVariable()
 {
-    QPointer<KDialog> dlg=new KDialog(this);
+    QPointer<QDialog> dlg=new QDialog(this);
     QWidget *widget=new QWidget(dlg);
     Ui::NewVariableDialogBase base;
     base.setupUi(widget);
-    dlg->setMainWidget(widget);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    dlg->setLayout(mainLayout);
+
+    base.buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
+    base.buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
+
+    connect(base.buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()) );
+    connect(base.buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()) );
+
+    mainLayout->addWidget(widget);
 
     if( dlg->exec())
     {
