@@ -153,7 +153,7 @@ void TextResultItem::toggleLatexCode()
 void TextResultItem::saveResult()
 {
     Cantor::Result* res = result();
-    const QString& filename = KFileDialog::getSaveFileName(KUrl(), res->mimeType(), worksheet()->worksheetView());
+    const QString& filename = KFileDialog::getSaveFileName(QUrl(), res->mimeType(), worksheet()->worksheetView());
     qDebug() << "saving result to " << filename;
     res->save(filename);
 }
